# Rokon Package

This package contains custom models for deep learning, specifically RNet models. You can use the following models in your projects:

- RNet1
- RNet2
- RNet3
- RNet4
- RNet5

## Installation

To install the package, run the following command:

```bash
!pip install rokon